function simSphere_n_Pendulum

% global M Gb Gn Gf D E U papp

%-----------------------------------------
% Set up params that define the simulation
sim.t0 = 0;     % Initial simluation time
sim.time = 0;   % Current simluation time
sim.h = 0.03;   % Simulation time step
sim.T = 20;     % Final simulation time  
sim.nd = 7;     % Number of friction directions.  CAN BE VARIED!!
sim.fps = 5;    % Number of frames to draw per second of simulation
sim.solver = 'lemke';
sim.solver = 'proxPGS';
sim.hotStart = 0;

%-----------------------------------------
% Set up body data structure.  This also sets the initial conditions.
nBodies = 2;   % Fixed number of bodies
nConts = 7;    % Fixed number of contacts (i.e., number of body pairs)
[body] = initBodies();

nJnts = 2;
nu_ell = [body(1).nu; body(2).nu];
u_ell =  [body(1).u;  body(2).u];
drawScene(body);   % Draw initial configuration of system

%-----------------------------------------
% Create arrays of solution for ploting trajectories
%    1:1 ---------------- kinetic energy
%    2:2 ---------------- potential energy
%   ????? --------------- nu
%   ????? --------------- pb
%   ????? --------------- pn
%   ????? --------------- alpha
%   ????? --------------- s
%   ????? --------------- u
%   ????? --------------- Psi_b
%   ????? --------------- Psi_n
%   ????? --------------- pf = D * alpha
nRows = 2 + 6*nBodies + 3*nJnts + nConts*(2+sim.nd) + 3*nJnts + nConts +  2*sim.nd;
time = sim.t0 : sim.h : sim.T;
nCols = length(time);
trajAll = zeros(nRows, nCols);

%-----------------------------------------
% Store the initial condition
% Kinetic energy
M = makeM(body); % Because bodies are spheres, M is constant for all time.
Minv = inv(M);   % Also constant
KE = nu_ell' * M * nu_ell / 2;
trajAll(1,1) = KE;

% Potential energy
grav = makeGrav;
PE = -grav' * (body(1).u(1:3) * body(1).mass ...
             + body(2).u(1:3) * body(2).mass);
trajAll(2,1) = PE;

% External Impulse
 %trajAll(?????, 1) = makePapp(body, sim);

% Velocities and configurations of bodies
% trajAll(?????, 1) = nu_ell;
% trajAll(?????, 1) = u_ell;

% Distances at contacts
% [Psi] = makePsi(body, sim);
% trajAll(?????, 1) = Psi.N;
% Psin_ell = Psi.N;

%-----------------------------------------
% Start the simulation
% Because all contacts are tracked every time step, U and E are constant
% U = makeU(body);  % U is constant for entire simulation
% E = makeE(sim);   % E is constant for entire simulation
% lcpSolnLast = zeros(12*(2+sim.nd), 1);
% mcpSolnLast = zeros(18 + 12*(2+sim.nd), 1);
frmTime = sim.t0;
for i = 1 : nCols 
%     [Gn, Gf, D, Gb] = makeG(body, sim); 
%     [Psi] = makePsi(body, sim);
%     papp = makePapp(body, sim);       % Input to drive the dynamics
%     V = makeV(body);                  % Needed for configuration update

    % Formulate standard LCP here
    
    
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
                       
%     % Guess solution
%     if sim.hotStart
%         lcpSoln0 = lcpSoln;
%         mcpSoln0 = mcpSoln;
%     else
%         lcpSoln0 = zeros(12*(2+sim.nd), 1);
%         mcpSoln0 = zeros(18 + 12*(2+sim.nd), 1);
%     end
%     switch sim.solver
%         case 'lemke'
%             [lcpSoln,err] = lemke(MM,qq,lcpSoln0); % Solve the subproblem
%         case 'proxPGS'
%             [lcpSoln,err] = proxPGS(MM,qq,lcpSoln0); % Solve the subproblem
%     end
    % Check error
%     if norm(err) > 1e-10
%         fprintf(strcat(solver, ':  LCP number = %5d    error = %12.6g\n'), i, err);
%     end

    
%     pn_ellp1 = lcpSoln(?????);
%     alpha_ellp1 = lcpSoln(?????);
%     s_ellp1  = lcpSoln(?????);
    
    % Update velocities and configurations of the bodies and the time.
    % Also compute the impulses of the bilateral constraints
%     nu_ellp1 = nu_ell + MinvGn*pn_ellp1 + MinvGf*pf_ellp1 + MinvPapp;
%     u_ellp1 = u_ell + V*nu_ellp1 * sim.h;
%     pb_ellp1 = ?????????

    % Update the body data structure
%     for j = 1 : nBodies
%         % Renormalize unit quaternions first
%         quat = u_ellp1(j*7-3 : j*7);
%         uQuat = quat / norm(quat);
%         u_ellp1(j*7-3 : j*7) = uQuat;
%         body(j).u  =  u_ellp1(j*7-6 : j*7);
%         body(j).nu = nu_ellp1(j*6-5 : j*6);
%     end
    
%     % Update the trajectory information
%     % Kinetic energy
%     KE = nu_ellp1' * M * nu_ellp1 / 2;
% 
%     % Potential energy
%     grav = makeGrav;
%     PE = -grav' * (body(1).u(1:3) * body(1).mass ...
%                  + body(2).u(1:3) * body(2).mass ...
%                  + body(3).u(1:3) * body(3).mass);
    
%     % Net contact impulses
%     netNormImp = Gn * pn_ellp1;
%     netFricImp = Gf * D * alpha_ellp1;
    
%     % Distances at contacts
%     [Psi] = makePsi(body, sim);
% 
%     trajAll(:,i) = [KE;  PE;  nu_ellp1;  pb_ellp1;  pn_ellp1;  alpha_lp1;
%                     s_ellp1;  u_ellp1;  Psi.B;  Psi.N;  pf_ellp1];

%     % Prepare for next iteration of the simulation
%     nu_ell = nu_ellp1;
%     u_ell  = u_ellp1;
%     Psin_ellm1 = Psin_ell;
%     Psin_ell = Psi.N;
%     vn_ellm1 = vn_ell;  %%%% Added for bounce effect %%%%%
%     vn_ell = Gn' * nu_ell;
    sim.time = sim.time + sim.h;
    if  sim.time - frmTime > 1 / sim.fps
        drawScene(body);
        frmTime = sim.time;
    end
end
% plotAll(time, trajAll, sim);
end